Skip to contents

CV.Nc is calculated from the variance of Nc, which depends on the probability of detection (pa). Here, Nc represents the number of detected calls, and independence between detections is assumed.

Usage

Nc_CV(Nc, pa, c)

Arguments

Nc
  • Number of calls detected in the dataset (see function countDetections())

pa
  • Average probability of detection in the study area (see function pDetInArea())

c
  • false discovery rate (proportion of false positive detections divided by the total number predicted positive)

Value

cv.Nc - coefficient of variation of the number of detected calls

Details

Rationale for this calculation Variance of a binomial process, pa, is: 1) sigma^2= n * pa * (1-pa)

We require n, the number of trials conducted, but we have Nc, the number of positive detections. So we correct for false positives, then scale true positives by pa to get total number of trials

  1. n = (Nc*(1-c)/pa; # n: the number of trials conducted We substitute the right hand side back into 1) to get: 3) sigma^2 = (Nc*(1-c)/papa(1-pa); dividing by and multiplying by pa is the same as multiplying by one, leaving

  2. sigma^2 = Nc * (1-c) * (1-pa)