Skip to contents

Software for estimating the density of animal vocalisations (calls) This package includes functions for estimating call density of animal sounds, especially those of low-frequency baleen whales, by applying the algorithms described by Danielle Harris. In particular these algorithms can be used to estimate call density using auxiliary information to estimate the probability of detection within an area. The specific auxiliary information required by this package comes from the sonar equation, specifically, distributions of source levels (SL), transmission losses (TL), and noise levels (NL).