Finds the minimum and maximum SNR values across all matching observer columns and returns pretty axis limits.
Examples
if (FALSE) { # \dontrun{
computeSNRLims(ap)
computeSNRLims(d, snr_prefix = c("snr_observer1", "snr_observer2"))
} # }
Finds the minimum and maximum SNR values across all matching observer columns and returns pretty axis limits.
if (FALSE) { # \dontrun{
computeSNRLims(ap)
computeSNRLims(d, snr_prefix = c("snr_observer1", "snr_observer2"))
} # }