Estimate noise level distribution for MC simulation from the noise measurements included in the snrInfo file, plus the SNR detection function.
Source:R/callDensitySupport.R
nlFromSnrInfo.RdEstimate noise level distribution for MC simulation from the noise measurements included in the snrInfo file, plus the SNR detection function.