Skip to contents

Given parameters of an acoustic detector and a callDensity simulation, simulate the detection of true positive and false positive calls and append this to the simulation.

Usage

simulateDetector(detParams, sim)

Arguments

detParams
  • A data.frame of parameters for simulating the acoustic detector. The simulated detector will follow a logistic curve 'plogis' with the 'location', and 'scale' specified in the columns of detParams. The detector will also have a false discovery rate, 'c' specified in detParams as well as a mean and standard deviation of the distribution of the false-positive-to-noise-ratio, 'fpMean', and 'fpSD' respectively.

sim
  • a simulation data.frame created by simCallLocation and simCallAcoustics

Value

sim - simulation data.frame with additional columns for the detector status and rows for false positives. Columns added by this function include: detect_table - logical indicating which calls were detected groundTruth - logical indicating whether the call is a true positive (1) or false positive (0). group - factor with three levels indicating whether the call is a true positive, false positive, or false negative.