Skip to contents

Change path to detection csv files

Usage

updateDetectionFolder(p, newFolder)

Arguments

p

Call density detector parameter data.frame

newFolder

relative or absolute path to where the detection files are located

Value

new detection parameters with filenames that have updated folders