Nc_CV: Coefficient of Variation (CV) of the number of detected calls (Nc).
Source:R/callDensityEstimate.R
Nc_CV.RdCV.Nc is calculated from the variance of Nc, which depends on the probability of detection (pa). Here, Nc represents the number of detected calls, and independence between detections is assumed.
Details
Rationale for this calculation Variance of a binomial process, pa, is: 1) sigma^2= n * pa * (1-pa)
We require n, the number of trials conducted, but we have Nc, the number of positive detections. So we correct for false positives, then scale true positives by pa to get total number of trials
n = (Nc*(1-c)/pa; # n: the number of trials conducted We substitute the right hand side back into 1) to get: 3) sigma^2 = (Nc*(1-c)/papa(1-pa); dividing by and multiplying by pa is the same as multiplying by one, leaving
sigma^2 = Nc * (1-c) * (1-pa)