Default names of output files for call density estimation
Source:R/callDensitySupport.R
defaultOutputFileNames.RdGiven data.frame of call density parameters, p, create default parameters and output file-names for Monte-Carlo modelling and estimating call-density. Append all of these parameters to the data.frame and return it.