WARNING: This function is not supported, and probably does not do what whatever you were hoping it might do. Perhaps consider function c_CV instead. CV of false discovery rate using Cochran approximation
Source:R/callDensityEstimate.R
falseDiscoveryCV.RdWARNING: This function is not supported, and probably does not do what whatever you were hoping it might do. Perhaps consider function c_CV instead. CV of false discovery rate using Cochran approximation