Ensures that base R's stats::predict() works correctly on objects that have been tagged with the "detFun" class by fitDetFun(). Without this, S4 dispatch for vglm objects fails because R sees "detFun" first and finds no registered S4 method for that class.
Usage
# S3 method for class 'detFun'
predict(object, ...)