Simulate transmission loss (TL) radials following geometric (spherical) spreading law.
Source:R/callDensitySim.R
simTLradials_20logR.RdCreate a TL data.frame with a column for range and subsequent columns for transmission loss, TL for radial transects around a recorder. Transects will have a total length of maxRange with increments between points along the transect of rangeStep. The number of radial transects is specified as numTransects such that the angular resolution of the transects will be 360/numTransects.